aboutsummaryrefslogtreecommitdiff
path: root/gcc/flags.h
diff options
context:
space:
mode:
authorRichard Stallman <rms@gnu.org>1992-03-14 05:07:15 +0000
committerRichard Stallman <rms@gnu.org>1992-03-14 05:07:15 +0000
commitd45cf215ee7cefef0044a6bd3ee1c2c7b2466039 (patch)
treeb51ea120d470bb8953e46b0885064feeb114b3a5 /gcc/flags.h
parent23b2ce53390902084893cd7eb735b2332c927b67 (diff)
downloadgcc-d45cf215ee7cefef0044a6bd3ee1c2c7b2466039.zip
gcc-d45cf215ee7cefef0044a6bd3ee1c2c7b2466039.tar.gz
gcc-d45cf215ee7cefef0044a6bd3ee1c2c7b2466039.tar.bz2
*** empty log message ***
From-SVN: r472
Diffstat (limited to 'gcc/flags.h')
-rw-r--r--gcc/flags.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/gcc/flags.h b/gcc/flags.h
index c1a04f0..747e7c4 100644
--- a/gcc/flags.h
+++ b/gcc/flags.h
@@ -25,7 +25,8 @@ enum debug_info_type
NO_DEBUG, /* Write no debug info. */
DBX_DEBUG, /* Write BSD .stabs for DBX (using dbxout.c). */
SDB_DEBUG, /* Write COFF for (old) SDB (using sdbout.c). */
- DWARF_DEBUG /* Write Dwarf debug info (using dwarfout.c). */
+ DWARF_DEBUG, /* Write Dwarf debug info (using dwarfout.c). */
+ XCOFF_DEBUG /* Write IBM/Xcoff debug info (using dbxout.c). */
};
/* Specify which kind of debugging info to generate. */
@@ -42,7 +43,7 @@ enum debug_info_level
/* Specify how much debugging info to generate. */
extern enum debug_info_level debug_info_level;
-#ifdef DBX_DEBUGGING_INFO
+#if defined (DBX_DEBUGGING_INFO) || defined (XCOFF_DEBUGGING_INFO)
/* Nonzero means use GDB-only extensions of DBX format. */
extern int use_gdb_dbx_extensions;
#endif
@@ -242,7 +243,7 @@ extern int flag_no_inline;
extern int flag_syntax_only;
-/* Nonzero means we should save auxilliary info into a .X file. */
+/* Nonzero means we should save auxiliary info into a .X file. */
extern int flag_gen_aux_info;